leaftools.list_durations_of_leaves_in_expr
==========================================

.. autofunction:: abjad.tools.leaftools.list_durations_of_leaves_in_expr.list_durations_of_leaves_in_expr
   :noindex:
